@ECHO Off
REM AEROPLUM batch file, based on PLUME one from HGSYSTEM 2.0
REM Modified by Lourens Post         10/92
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

REM
ECHO AP============== Start of AEROPLUME batch file ======================
REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model AEROPLUME with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .API, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .API,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .API).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .API).
ECHO   The file SKELETON.API can be copied from %HGSYSTEM%\STINPUT as a
ECHO   template for an input data file *.API.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.API GOTO CHECKDD
ECHO AEROPLUME - Input file %0.API does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO AEROPLUME - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.API > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.API
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO AEROPLUME - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.API DEL $CONCAT$.API
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.API+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.API %0.API > NUL:
IF EXIST $CONCAT$.API DEL $CONCAT$.API
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.APD GOTO DICTOK
ECHO DICT.APD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during AEROPLUME run
REM
IF EXIST %0.APE DEL %0.APE
IF EXIST %0.APD DEL %0.APD
IF EXIST %0.APR DEL %0.APR
IF EXIST %0.AP1 DEL %0.AP1
IF EXIST %0.AP2 DEL %0.AP2
IF EXIST %0.AP3 DEL %0.AP3
IF EXIST %0.APM DEL %0.APM
IF EXIST %0.APS DEL %0.APS
IF EXIST %0.APX DEL %0.APX
IF EXIST %0.APZ DEL %0.APZ
IF EXIST %0.APW DEL %0.APW
IF EXIST %0.APN DEL %0.APN
IF EXIST %0.PGL DEL %0.PGL
IF EXIST %0.HSL DEL %0.HSL
IF EXIST %0.HTL DEL %0.HTL
IF EXIST %0.MMO DEL %0.MMO

REM ----make a copy of the free-format input file
copy /b %0.API %0.TMI > NUL
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO API >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.APD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.APD, %0.TMI
REM Output: %0.API, %0.APF, %0.APU
REM         %0.TME (in case of errors)

 %HGSYSTEM%\FFMAIN 
rem FFMAIN %0.APE CON
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI > NUL
IF EXIST %0.APF DEL %0.APF > NUL
REM
REM ----check if error file exists
REM
IF EXIST %0.APE GOTO APERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME > NUL
IF EXIST %0.APU DEL %0.APU > NUL
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.APU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO AEROPLUME calculations are being performed
REM
REM ---- copy name of analysis to file (to set file names in APMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO API >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.APD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.APU
REM Output: %0.APR, %0.AP1, %0.AP2, %0.AP3, %0.APM
REM         %0.APS, %0.APX, %0.APZ
REM         %0.HSL, %0.HTL, %0.PGL (if links successful)
REM         %0.APE, %0.APN (in case of errors)
REM         %0.APW (in case of warnings)
REM         %0.MMO (if MMES options used)

%HGSYSTEM%\APMAIN 
rem APMAIN %0.APE CON

REM RUN77 D:\AEROPLUM\APMAIN /BREAK

REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.APU DEL %0.APU

REM Get rid of SPRINT debug file if it is empty.
REM We use a trick: if a file is empty then copying it will fail:
REM no copy file will be made. We test for the existence of the copy
REM file to check whether the original file is empty.
copy /b %0.APS DUMMY.DUM > NUL
IF EXIST DUMMY.DUM GOTO SPREX
DEL %0.APS
GOTO NODUM
:SPREX
DEL DUMMY.DUM > NUL
:NODUM

IF EXIST %0.APE GOTO APERR
GOTO APCONT
:APERR
ECHO -----------------------------------------------------
ECHO                ***** ERRORS *****
ECHO ERRORS have been found during this AEROPLUME run
ECHO See the file %0.APE for the error messages
:APCONT

rem IF EXIST %0.AP1 DEL %0.AP1
rem  IF EXIST %0.AP2 DEL %0.AP2
rem IF EXIST %0.AP3 DEL %0.AP3
rem IF EXIST %0.APN DEL %0.APN
rem IF EXIST %0.APX DEL %0.APX
rem IF EXIST %0.APD DEL %0.APD
rem  IF EXIST %0.APZ DEL %0.APZ

ECHO End of AEROPLUME run
IF EXIST %0.APW ECHO -----------------------------------------------------------
IF EXIST %0.APW ECHO ***** There are WARNING MESSAGES in file %0.APW *****
ECHO ---------------------------------------------------------------------
IF EXIST %0.APR ECHO Main output data in file %0.APR
IF EXIST %0.AP1 ECHO Assist-data for manual matching to PGPLUME in file %0.AP1
IF EXIST %0.AP2 ECHO Assist-data for manual matching to HEGADAS-S in file %0.AP2
IF EXIST %0.AP3 ECHO Mixture composition details in file %0.AP3
IF EXIST %0.APZ ECHO Detailed info on matching criteria values in file %0.APZ
IF EXIST %0.APM ECHO Monitor messages in file %0.APM
IF EXIST %0.MMO ECHO Info on MMES options in file %0.MMO
ECHO ---------------------------------------------------------------------
IF EXIST %0.APN ECHO NAESOL diagnostics in file %0.APN
IF EXIST %0.APS ECHO SPRINT messages in file %0.APS
IF EXIST %0.APX ECHO Spreadsheet ASCII data in file %0.APX
IF EXIST %0.APD ECHO SPRINT debug messages in file %0.APD
ECHO ---------------------------------------------------------------------
IF EXIST %0.PGL ECHO PGPLUME input data in link file %0.PGL
IF EXIST %0.HSL ECHO HEGADAS-S input data in link file %0.HSL
IF EXIST %0.HTL ECHO HEGADAS-T input data in link file %0.HTL
:EXIT
ECHO AP============== End of AEROPLUME batch file ========================
