@ECHO OFF
ECHO G2============== Start of GET2COL batch file ================
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run program GET2COL with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .G2I, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .G2I,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .G2I).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .G2I).
ECHO   The file SKELETON.G2I can be copied from %HGSYSTEM%\STINPUT as a
ECHO   template for an input data file *.G2I.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.G2I GOTO CHECKDD
ECHO GET2COL - Input file %0.G2I does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO GET2COL - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.G2I > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.G2I
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO GET2COL - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.G2I DEL $CONCAT$.G2I
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.G2I+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.G2I %0.G2I > NUL:
IF EXIST $CONCAT$.G2I DEL $CONCAT$.G2I
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.G2D GOTO DICTOK
ECHO DICT.G2D data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during GET2COL run
REM
IF EXIST %0.G2R DEL %0.G2R
IF EXIST %0.G2E DEL %0.G2E
IF EXIST %0.G2B DEL %0.G2B
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.G2I %0.TMI >NUL:
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO G2I >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.G2D >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.G2D, %0.TMI
REM Output: %0.G2I, %0.G2F, %0.G2U
REM         %0.TME (in case of errors)
 %HGSYSTEM%\FFMAIN 
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.G2F DEL %0.G2F
REM
REM ----check if error file exists
REM
IF EXIST %0.G2E GOTO G2ERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME
IF EXIST %0.G2U DEL %0.G2U
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.G2U GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO GET2COL operations are being performed
REM
REM ---- copy name of analysis to file (to set file names in G2COLP)
REM
ECHO %0 > HGSYST$$.TIT
ECHO G2I >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.G2D >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.G2U
REM Output: %0.G2R
REM         %0.G2E (in case of errors)
 %HGSYSTEM%\G2COLP
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.G2U DEL %0.G2U
IF EXIST %0.G2B DEL %0.G2B
IF EXIST %0.G2E GOTO G2ERR
GOTO G2CONT
:G2ERR
ECHO ERRORS have been found during GET2COL run
ECHO See the file %0.G2E for list of errors
ECHO G2-----------------------------------------------------------
:G2CONT
ECHO End of GET2COL
IF EXIST %0.G2R ECHO Output summary in file %0.G2R
:EXIT
ECHO G2============== End   of GET2COL batch file ================
