@ECHO OFF

ECHO HS============== Start of HEGADAS-S batch file ================
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model HEGADAS-S with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .HSI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .HSI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .HSI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .HSI).
ECHO   One of the four basic HEGADAS-S input files STPOOLNO.HSI,
ECHO   STBRKNO.HSI, STPOOLHF.HSI, STBRKHF.HSI  can be copied from
ECHO   F:\HGSYSTEM\STINPUT as a template for an input data file *.HSI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.HSI GOTO CHECKDD
ECHO HEGADASS - Input file %0.HSI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO HEGADASS - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.HSI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.HSI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO HEGADASS - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.HSI DEL $CONCAT$.HSI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.HSI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.HSI %0.HSI > NUL:
IF EXIST $CONCAT$.HSI DEL $CONCAT$.HSI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.HSD GOTO DICTOK
ECHO DICT.HSD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during HEGADASS run
REM
IF EXIST %0.HSE DEL %0.HSE
IF EXIST %0.HSR DEL %0.HSR
IF EXIST %0.HS1 DEL %0.HS1
IF EXIST %0.HSF DEL %0.HSF
IF EXIST %0.HSM DEL %0.HSM
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.HSI %0.TMI >NUL:
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO HSI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.HSD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, F:\HGSYSTEM\DICT.HSD, %0.TMI
REM Output: %0.HSI, %0.HSF, %0.HSU
REM         %0.TME (in case of errors)
 %HGSYSTEM%\FFMAIN 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.HSF DEL %0.HSF
REM
REM ----check if error file exists
REM
IF EXIST %0.HSE GOTO HSERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME
IF EXIST %0.HSU DEL %0.HSU
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.HSU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO HEGADAS-S calculations are being performed
REM
REM ---- copy name of analysis to file (to set file names in HSMAIN)
REM
ECHO %0 > HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.HSU
REM Output: %0.HSR, %0.HSM, %0.HS1 (if ICNT.GT.0), %0.HSF (for HF)
REM         %0.HSE (in case of errors)

 %HGSYSTEM%\HSMAIN 

REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.HSU DEL %0.HSU
IF EXIST %0.HSE GOTO HSERR
GOTO HSCONT
:HSERR
ECHO ERRORS have been found during HEGADAS-S run
ECHO See the file %0.HSE for list of errors
ECHO HS--------------------------------------------------------
:HSCONT
ECHO End of HEGADAS-S
IF EXIST %0.HSR ECHO Output in file %0.HSR
IF EXIST %0.HS1 ECHO Isoconcentration and cumulative cloud data in file %0.HS1
IF EXIST %0.HSF ECHO Specific HF output data in file %0.HSF
IF EXIST %0.HSM ECHO Input data for post-processor POSTHS in binary file %0.HSM
:EXIT
ECHO HS============== End   of HEGADAS-S batch file ================
