@ECHO OFF
ECHO HF============== Start of HFFLASH batch file ================
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model HFFLASH with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .HFI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .HFI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .HFI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .HFI).
ECHO   The file SKELETON.HFI can be copied from %HGSYSTEM%\STINPUT as a
ECHO   template for an input data file *.HFI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.HFI GOTO CHECKDD
ECHO HFFLASH - Input file %0.HFI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO HFFLASH - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.HFI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.HFI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO HFFLASH - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.HFI DEL $CONCAT$.HFI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.HFI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.HFI %0.HFI > NUL:
IF EXIST $CONCAT$.HFI DEL $CONCAT$.HFI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.HFD GOTO DICTOK
ECHO DICT.HFD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during HFFLASH run
REM
IF EXIST %0.HFE DEL %0.HFE
IF EXIST %0.HFR DEL %0.HFR
IF EXIST %0.HFN DEL %0.HFN
IF EXIST %0.HSL DEL %0.HSL
IF EXIST %0.HTL DEL %0.HTL
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.HFI %0.TMI >NUL:
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO HFI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.HFD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.HFD, %0.TMI
REM Output: %0.HFI, %0.HFF, %0.HFU
REM         %0.TME (in case of errors)

%HGSYSTEM%\FFMAIN 

REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.HFF DEL %0.HFF
REM
REM ----check if error file exists
REM
IF EXIST %0.HFE GOTO HFERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME
IF EXIST %0.HFU DEL %0.HFU
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.HFU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO HFFLASH calculations are being performed
REM
REM ---- copy name of analysis to file (to set file names in HFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO HFI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.HFD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.HFU
REM Output: %0.HFR
REM         %0.HSL, %0.HTL (if links successful)
REM         %0.HFE, %0.HFN (in case of errors)

%HGSYSTEM%\HFMAIN 

REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.HFU DEL %0.HFU
IF EXIST %0.HFE GOTO HFERR
IF EXIST %0.HFN DEL %0.HFN
GOTO HFCONT
:HFERR
ECHO ERRORS have been found during HFFLASH run
ECHO See the file %0.HFE for list of errors
ECHO HF-----------------------------------------------------------
:HFCONT
ECHO End of HFFLASH
IF EXIST %0.HFR ECHO Output in file %0.HFR
IF EXIST %0.HFN ECHO Numerical diagnostics in file %0.HFN
IF EXIST %0.HSL ECHO HEGADAS-S input (HF-gas) data stored in file %0.HSL
IF EXIST %0.HTL ECHO HEGADAS-T input (HF-gas) data stored in file %0.HTL
:EXIT
ECHO HF============== End   of HFFLASH batch file ================
