@ECHO OFF
ECHO LP============== Start of LPOOL batch file ================
REM
REM  LPOOL batch file for version using LSM90.
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model LPOOL with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .LPI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .LPI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .LPI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .LPI).
ECHO   Basic LPOOL input files .LPI can be copied from %HGSYSTEM%\STINPUT
ECHO   as a template for an input
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.LPI GOTO CHECKDD
ECHO LPOOL - Input file %0.LPI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO LPOOL - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.LPI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.LPI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO LPOOL - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.LPI DEL $CONCAT$.LPI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.LPI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.LPI %0.LPI > NUL:
IF EXIST $CONCAT$.LPI DEL $CONCAT$.LPI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.LPD GOTO DICTOK
ECHO DICT.LPD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during LPOOL run
REM
IF EXIST %0.LPE DEL %0.LPE
IF EXIST %0.LPR DEL %0.LPR
IF EXIST %0.LPC DEL %0.LPC
IF EXIST %0.LPS DEL %0.LPS
IF EXIST %0.LPT DEL %0.LPT
IF EXIST %0.LPH DEL %0.LPH
IF EXIST %0.LPD DEL %0.LPD
IF EXIST %0.HTL DEL %0.HTL
IF EXIST LSM90.IN DEL LSM90.IN
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.LPI %0.TMI >NUL:
REM
REM ----copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO LPI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.LPD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.LPD, %0.TMI
REM Output: %0.LPI, %0.LPF, %0.LPU
REM         %0.TME (in case of errors)
%HGSYSTEM%\FFMAIN 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.LPF DEL %0.LPF
REM
REM ----check if error file exists
REM
IF EXIST %0.LPE GOTO LPERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME
IF EXIST %0.LPU DEL %0.LPU
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.LPU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO LPOOL calculations are being performed
REM
REM ----copy name of analysis to file (to set file names in LPMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO LPI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.LPD >> HGSYST$$.TIT
REM  Input: HGSYST$$.TIT, %0.LPU
REM  Output: %0.LPR, %0.LPE (in case of errors), and several other files
REM          %0.HSL (if steady), %0.HTL (if transient)

%HGSYSTEM%\LPMAIN 

REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.LPU DEL %0.LPU

IF EXIST %0.LPE GOTO LPERR
GOTO LPCONT
:LPERR
ECHO     *********** ERRORS ************
ECHO ERRORS have been found during this LPOOL run
ECHO See the file %0.LPE for list of errors
:LPCONT

REM Get rid of LSM90 debug file if it is empty.
REM We use a trick: if a file is empty then copying it will fail:
REM no copy file will be made. We test for the existence of the copy
REM file to check whether the original file is empty.
copy /b %0.LPD DUMMY.DUM > NUL
IF EXIST DUMMY.DUM GOTO BUGEX
DEL %0.LPD > nul
GOTO NODUM
:BUGEX
DEL DUMMY.DUM > NUL
:NODUM

REM Get rid of LSM90 pool composition file if it is empty.
REM Use same trick.
copy /b %0.LPS DUMMY.DUM > NUL
IF EXIST DUMMY.DUM GOTO POOLEX
DEL %0.LPS > nul
GOTO NODUM1
:POOLEX
DEL DUMMY.DUM > NUL
:NODUM1

REM Get rid of LSM90 cloud composition file if it is empty.
REM Use same trick.
copy /b %0.LPC DUMMY.DUM > NUL
IF EXIST DUMMY.DUM GOTO CLOUDEX
DEL %0.LPC > nul
GOTO NODUM2
:CLOUDEX
DEL DUMMY.DUM > NUL
:NODUM2

:ERREXIT

REM LSM90.IN is a (temporary) input file for LSM90, created by LPOOL
IF EXIST LSM90.IN DEL LSM90.IN
IF EXIST %0.LPH DEL %0.LPH
IF EXIST %0.LPX DEL %0.LPX

ECHO End of LPOOL run
ECHO ---------------------------------------------------------------------
IF EXIST %0.LPR ECHO Main output data in file %0.LPR
ECHO ---------------------------------------------------------------------
IF EXIST %0.LPC ECHO Vapour cloud composition details in %0.LPC
IF EXIST %0.LPS ECHO Pool composition details in %0.LPS
IF EXIST %0.LPT ECHO Emission rates in %0.LPT
IF EXIST %0.LPH ECHO Heat transfer details in %0.LPH
IF EXIST %0.LPX ECHO Expansion info in %0.LPX
ECHO ---------------------------------------------------------------------
IF EXIST %0.HTL ECHO HEGADAS-T input data (pool data) stored in file %0.HTL
:EXIT
ECHO LP============== End of LPOOL batch file ================
