@ECHO OFF
ECHO PS============== Start of POSTHS batch file ================
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run program POSTHS with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .PSI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .PSI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .PSI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .PSI).
ECHO   The file SKELETON.PSI can be copied from %HGSYSTEM%\STINPUT as a
ECHO   template for an input data file *.PSI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.PSI GOTO CHECKDD
ECHO POSTHS - Input file %0.PSI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO POSTHS - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.PSI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.PSI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO POSTHS - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.PSI DEL $CONCAT$.PSI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.PSI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.PSI %0.PSI > NUL:
IF EXIST $CONCAT$.PSI DEL $CONCAT$.PSI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.PSD GOTO DICTOK
ECHO DICT.PSD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during POSTHS run
REM
IF EXIST %0.PSR DEL %0.PSR
IF EXIST %0.PSE DEL %0.PSE
REM
ECHO Input validation is in progress
REM
REM ----make a copy of the free-format input file
REM
copy /b %0.PSI %0.TMI >NUL:
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO PSI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.PSD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.PSD, %0.TMI
REM Output: %0.PSI, %0.PSF, %0.PSU
REM         %0.TME (in case of errors)
 %HGSYSTEM%\FFMAIN 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI
IF EXIST %0.PSF DEL %0.PSF
REM
REM ----check if error file exists
REM
IF EXIST %0.PSE GOTO PSERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME
IF EXIST %0.PSU DEL %0.PSU
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.PSU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO POSTHS operations are being performed
REM
REM ---- copy name of analysis to file (to set file names in PSMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO PSI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.PSD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.PSU
REM Output: %0.PSR
REM         %0.PSE (in case of errors)
%HGSYSTEM%\PSMAIN
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.PSU DEL %0.PSU
IF EXIST %0.PSE GOTO PSERR
GOTO PSCONT
:PSERR
ECHO ERRORS have been found during POSTHS run
ECHO See the file %0.PSE for list of errors
ECHO PS-----------------------------------------------------------
:PSCONT
ECHO End of POSTHS
IF EXIST %0.PSR ECHO Output summary in file %0.PSR
:EXIT
ECHO PS============== End   of POSTHS batch file ================
