@ECHO OFF
REM
REM SPILL batch file, based on AEROPLUME one from HGSYSTEM 2.2
REM Modified by Lourens Post, October 1993
REM Modified by Steve Richardson     12/96
REM
REM Set the environment variable to the shared drive

REM
ECHO SP============== Start of SPILL batch file ======================
REM
REM ----check at least one input argument; if not, terminate
REM
IF NOT %1.==. GOTO ARGOK
ECHO   Run model SPILL with 1 to n input files as required.
ECHO   Parameters should be entered as follows :-
ECHO    1 to n-1  input files to be concatenated, with file names
ECHO              of the form FILENAME.EXT
ECHO    n         identifier for this run, with file name
ECHO              of the form FILENAME     (N.B. NO EXTENSION)
ECHO              (system assumes extension .SPI, and uses/creates
ECHO              (files with this name and various extensions).
ECHO    if n=1    the file must already exist with the extension .SPI,
ECHO              but the extension must not be included.
ECHO    if n=2    the first file must already exist with its specified
ECHO              extension, and the file will be copied to the
ECHO              second file (system assumes extension .SPI).
ECHO    else      n-1 files must already exist with their specified
ECHO              extensions, and they will be concatenated and copied
ECHO              to the n'th file (system assumes extension .SPI).
ECHO   The file SKELETON.SPI can be copied from %HGSYSTEM%\STINPUT as a
ECHO   template for an input data file *.SPI.
GOTO EXIT
:ARGOK
REM
REM ----SHIFT eliminates first argument and moves all others down one
REM
SHIFT
REM
REM ----check if only one input argument specified
REM
IF NOT %1.==. GOTO NUMARGS
REM
REM ----one argument; check if the input file exists
REM ----if yes, check data dictionary; if not, terminate
REM
IF EXIST %0.SPI GOTO CHECKDD
ECHO SPILL - Input file %0.SPI does not exist - program terminated
GOTO EXIT
:NUMARGS
REM
REM ----check if only two input arguments specified
REM
IF NOT %2.==. GOTO CONCAT
REM
REM ----two arguments; check if first file exists; if not, terminate
REM
IF EXIST %0 GOTO COPY1
ECHO SPILL - Input file %0 does not exist - program terminated
GOTO EXIT
:COPY1
REM
REM ----copy file, do not concatenate, check data dictionary
REM
copy /b %0 %1.SPI > NUL:
SHIFT
GOTO CHECKDD
:CONCAT
REM
REM ----more than two arguments; create CONCAT key in temporary file
REM
ECHO = CONCAT == > $CONCAT$.SPI
:CHECKN
REM
REM ----check if input file exists; if not, terminate
REM
IF EXIST %0 GOTO COPYN
ECHO SPILL - Input file %0 does not exist - program terminated
IF EXIST $CONCAT$.SPI DEL $CONCAT$.SPI
GOTO EXIT
:COPYN
REM
REM ----copy input file at end of temporary file
REM
copy /b $CONCAT$.SPI+%0 > NUL:
REM
REM ----is there another file to concatenate?
REM
SHIFT
IF NOT %1.==. GOTO CHECKN
REM
REM ----no more files to concatenate; copy to final file
REM
copy /b $CONCAT$.SPI %0.SPI > NUL:
IF EXIST $CONCAT$.SPI DEL $CONCAT$.SPI
:CHECKDD
REM
REM ----check if preprocessed data dictionary exists; if not, terminate
REM
IF EXIST %HGSYSTEM%\DICT.SPD GOTO DICTOK
ECHO DICT.SPD data dictionary does not exist - program terminated
GOTO EXIT
:DICTOK
REM
REM ----delete all files which might be generated during SPILL run
REM
IF EXIST %0.SPE DEL %0.SPE
IF EXIST %0.SPD DEL %0.SPD
IF EXIST %0.SPR DEL %0.SPR
IF EXIST %0.SPC DEL %0.SPC
IF EXIST %0.SPM DEL %0.SPM
IF EXIST %0.SPS DEL %0.SPS
IF EXIST %0.SPX DEL %0.SPX
IF EXIST %0.SPW DEL %0.SPW
IF EXIST %0.SPN DEL %0.SPN
IF EXIST %0.APL DEL %0.APL

REM ----make a copy of the free-format input file
copy /b %0.SPI %0.TMI > NUL
REM
REM ---- copy name of analysis to file (to set file names in FFMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO SPI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.SPD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %HGSYSTEM%\DICT.SPD, %0.TMI
REM Output: %0.SPI, %0.SPF, %0.SPU
REM         %0.TME (in case of errors)
%HGSYSTEM%\FFMAIN 
REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.TMI DEL %0.TMI > NUL
IF EXIST %0.SPF DEL %0.SPF > NUL
REM
REM ----check if error file exists
REM
IF EXIST %0.SPE GOTO SPERR
IF NOT EXIST %0.TME GOTO FFOK
ECHO Input errors exist - check input file - program terminated
IF EXIST %0.TME DEL %0.TME > NUL
IF EXIST %0.SPU DEL %0.SPU > NUL
GOTO EXIT
:FFOK
REM
REM ----check if unformatted input file exists; if not, terminate
REM
IF EXIST %0.SPU GOTO UNFOK
ECHO Unformatted input file not available - program terminated
GOTO EXIT
:UNFOK
ECHO SPILL calculations are being performed
REM
REM ---- copy name of analysis to file (to set file names in SPMAIN)
REM
ECHO %0 > HGSYST$$.TIT
ECHO SPI >> HGSYST$$.TIT
ECHO %HGSYSTEM%\DICT.SPD >> HGSYST$$.TIT
REM Input: HGSYST$$.TIT, %0.SPU
REM Output: %0.SPR, %0.SPC, %0.SPM
REM         %0.SPS, %0.SPX
REM         %0.APL (AEROPLUME link file)
REM         %0.SPE, %0.SPN (in case of errors)
REM         %0.SPW (in case of warnings)

%HGSYSTEM%\SPMAIN 

REM
REM ----erase temporary files
REM
IF EXIST HGSYST$$.TIT DEL HGSYST$$.TIT
IF EXIST %0.SPU DEL %0.SPU

REM Get rid of SPRINT debug file if it is empty.
REM We use a trick: if a file is empty then copying it will fail:
REM no copy file will be made. We test for the existence of the copy
REM file to check whether the original file is empty.
copy /b %0.SPS DUMMY.DUM > NUL
IF EXIST DUMMY.DUM GOTO SPREX
DEL %0.SPS
GOTO NODUM
:SPREX
DEL DUMMY.DUM > NUL
:NODUM

IF EXIST %0.SPE GOTO SPERR
GOTO SPCONT
:SPERR
ECHO -----------------------------------------------------
ECHO                ***** ERRORS *****
ECHO ERRORS have been found during this SPILL run
ECHO See the file %0.SPE for the error messages
:SPCONT

REM IF EXIST %0.SPC DEL %0.SPC
IF EXIST %0.SPN DEL %0.SPN
REM IF EXIST %0.SPX DEL %0.SPX
REM IF EXIST %0.SPD DEL %0.SPD

ECHO End of SPILL run
IF EXIST %0.SPW ECHO -----------------------------------------------------------
IF EXIST %0.SPW ECHO ***** There are WARNING MESSAGES in file %0.SPW *****
ECHO ---------------------------------------------------------------------
IF EXIST %0.SPR ECHO Main output data in file %0.SPR
IF EXIST %0.SPC ECHO Mixture composition details in file %0.SPC
IF EXIST %0.SPM ECHO Monitor messages in file %0.SPM
ECHO ---------------------------------------------------------------------
IF EXIST %0.SPN ECHO NAESOL diagnostics in file %0.SPN
IF EXIST %0.SPS ECHO SPRINT messages in file %0.SPS
IF EXIST %0.SPX ECHO Spreadsheet ASCII data in file %0.SPX
IF EXIST %0.SPD ECHO SPRINT debug messages in file %0.SPD
ECHO ---------------------------------------------------------------------
IF EXIST %0.APL ECHO AEROPLUME input data in link file %0.APL
:EXIT
ECHO SP============== End of SPILL batch file ========================
